BubbleShape enum

This file defines the shape of the bubble in the navigation bar.

Inheritance
Available extensions

Values

circular → const BubbleShape

Represents a circular bubble shape.

square → const BubbleShape

Represents a square bubble shape.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape double

Available on BubbleShape, provided by the BubbleShapeExtension extension

Returns the shape value based on the bubble shape type.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BubbleShape>
A constant List of the values in this enum, in order of their declaration.