BubbleShapeExtension extension
Extension to get the shape value for the bubble.
- on
Properties
- shape → double
-
Available on BubbleShape, provided by the BubbleShapeExtension extension
Returns the shape value based on the bubble shape type.no setter